@@ -18,30 +18,30 @@
 #ifndef BOOM_POISSON_PROCESS_HPP_
 #define BOOM_POISSON_PROCESS_HPP_
 
-#include <Models/ModelTypes.hpp>
-#include <cpputil/DateTime.hpp>
-#include <Models/PointProcess/PointProcess.hpp>
 #include <functional>
+#include "Models/ModelTypes.hpp"
+#include "Models/PointProcess/PointProcess.hpp"
+#include "cpputil/DateTime.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   struct NullDataGenerator {
-    Data* operator()(){return 0;}
+    Data *operator()() { return 0; }
   };
 
   // A base class for the Poisson process.  The
   // HomogeneousPoissonProcess and variaous flavors of inhomogeneous
   // poisson processes can generalize.
-  class PoissonProcess : virtual public Model{
+  class PoissonProcess : virtual public Model {
    public:
-    PoissonProcess *clone()const override =0;
+    PoissonProcess *clone() const override = 0;
 
     // lambda(t)
-    virtual double event_rate(const DateTime &t)const=0;
+    virtual double event_rate(const DateTime &t) const = 0;
 
     // Integral of lambda(t) from t0 to t1.
     virtual double expected_number_of_events(const DateTime &t0,
-                                             const DateTime &t1)const=0;
+                                             const DateTime &t1) const = 0;
 
     // Adding data
     virtual void add_exposure_window(const DateTime &t0,
@@ -53,12 +53,10 @@ namespace BOOM{
     // the process will include marks for those events where the
     // returned value is non-NULL.
     virtual PointProcess simulate(
-        RNG &rng,
-        const DateTime &t0,
-        const DateTime &t1,
-        std::function<Data*()> mark_generator = NullDataGenerator()) const = 0;
+        RNG &rng, const DateTime &t0, const DateTime &t1,
+        std::function<Data *()> mark_generator = NullDataGenerator()) const = 0;
   };
 
-}
+}  // namespace BOOM
 
-#endif // BOOM_POISSON_PROCESS_HPP_
+#endif  // BOOM_POISSON_PROCESS_HPP_
