@@ -125,15 +125,63 @@ namespace BOOM {
   // Returns:
   //   This observation's contribution to log likelihood.
   double sparse_multivariate_kalman_update(
-      const ConstVectorView &observation, Vector &state_conditional_mean,
-      SpdMatrix &state_conditional_variance, Matrix &kalman_gain,
+      const ConstVectorView &observation,
+      Vector &state_conditional_mean,
+      SpdMatrix &state_conditional_variance,
+      Matrix &kalman_gain,
       SpdMatrix &forecast_error_precision,
-      double &forecast_precision_log_determinant, Vector &forecast_error,
-      bool missing, const SparseKalmanMatrix &observation_coefficients,
+      double &forecast_precision_log_determinant,
+      Vector &forecast_error,
+      bool missing,
+      const SparseKalmanMatrix &observation_coefficients,
       const SpdMatrix &observation_variance,
       const SparseKalmanMatrix &transition_matrix,
       const SparseKalmanMatrix &RQR);
 
+  // For computing the forecast error precision in the case of highly
+  // multivariate conditionally independent data.
+  //
+  // The observation variance of such data is diagonal, and the dimension of
+  // the state is (potentially) much smaller than the dimension of the data.
+  //
+  // The forecast error variance is F = H + ZPZ', where H is diagonal and P is
+  // low dimensional.
+  //
+  // The Woodbury formula tells us that F.inverse is
+  //
+  // H.inv - H.inv * Z * (P.inv + Z' * H.inv * Z).inv * Z' * H.inv
+  //
+  // Args:
+  //   observation_precision: A vector containing the precisions of the errors
+  //     from the observation equation.
+  //   observation_coefficients:  The matrix relating 
+  SpdMatrix WoodburyInverse(const Vector &observation_precision,
+                            const SparseKalmanMatrix &observation_coefficients,
+                            const SpdMatrix &state_conditional_variance,
+                            double logdet_observation_precision,
+                            double &log_determinant);
+
+  // A WoodburyInverse formula for constant observation variances (i.e. a scalar
+  // times the identity.
+  SpdMatrix WoodburyInverse(double observation_precision,
+                            const SparseKalmanMatrix &observation_coefficients,
+                            const SpdMatrix &state_conditional_variance,
+                            double &log_determinant);
+  
+  double sparse_conditionally_independent_kalman_update(
+      const ConstVectorView &observation,
+      Vector &state_conditional_mean,
+      SpdMatrix &state_conditional_variance,
+      Matrix &kalman_gain,
+      const SpdMatrix &forecast_error_precision,
+      double &forecast_precision_log_determinant,
+      Vector &forecast_error,
+      bool missing,
+      const SparseKalmanMatrix &observation_coefficients,
+      const DiagonalMatrix &observation_variance,
+      const SparseKalmanMatrix &transition_matrix,
+      const SparseKalmanMatrix &RQR);
+  
   // Updates a[t] and P[t] to condition on all Y, and sets up r and N
   // for use in the next recursion.
   void sparse_scalar_kalman_smoother_update(
