@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -15,35 +16,29 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <Models/Policies/PriorPolicy.hpp>
-#include <Models/PosteriorSamplers/PosteriorSampler.hpp>
+#include "Models/Policies/PriorPolicy.hpp"
+#include "Models/PosteriorSamplers/PosteriorSampler.hpp"
 
-
-namespace BOOM{
+namespace BOOM {
   typedef PriorPolicy PP;
 
-  void PP::set_method(Ptr<PosteriorSampler> sam){
+  void PP::set_method(const Ptr<PosteriorSampler> &sam) {
     samplers_.push_back(sam);
   }
 
-
-  void PP::sample_posterior(){
-    for(uint i=0; i<samplers_.size(); ++i){
+  void PP::sample_posterior() {
+    for (uint i = 0; i < samplers_.size(); ++i) {
       samplers_[i]->draw();
     }
   }
 
-  double PP::logpri()const{
-    double ans=0;
-    for(uint i=0; i<samplers_.size(); ++i) ans+=samplers_[i]->logpri();
+  double PP::logpri() const {
+    double ans = 0;
+    for (uint i = 0; i < samplers_.size(); ++i) ans += samplers_[i]->logpri();
     return ans;
   }
 
-  void PP::clear_methods(){
-    samplers_.clear();
-  }
+  void PP::clear_methods() { samplers_.clear(); }
 
-  int PP::number_of_sampling_methods() const {
-    return samplers_.size();
-  }
-}
+  int PP::number_of_sampling_methods() const { return samplers_.size(); }
+}  // namespace BOOM
