@@ -120,13 +120,13 @@ namespace BOOM {
   // likelihood assumes that n_ and the cholesky factor of sumsq_ have
   // been precomputed.
   double SepStratSampler::logp0(const SpdMatrix &Sigma, double alpha) const {
-    Chol L(Sigma);
+    Cholesky L(Sigma);
     if (!L.is_pos_def()) return BOOM::negative_infinity();
 
     double ans = logprior(Sigma);
     if (ans == BOOM::negative_infinity()) return ans;
     ans += -.5 * (n_ * alpha * L.logdet() +
-                  L.solve(sqrt(alpha) * sumsq_upper_chol_.t()).sumsq());
+                  L.solve(sqrt(alpha) * sumsq_upper_chol_.transpose()).sumsq());
     return ans;
   }
   //----------------------------------------------------------------------
