@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2012 Steven L. Scott
 
@@ -15,26 +16,23 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <Models/ZeroInflatedPoissonModel.hpp>
-#include <Models/PosteriorSamplers/ZeroInflatedPoissonSampler.hpp>
-#include <distributions.hpp>
+#include "Models/PosteriorSamplers/ZeroInflatedPoissonSampler.hpp"
+#include "Models/ZeroInflatedPoissonModel.hpp"
+#include "distributions.hpp"
 
 namespace BOOM {
   ZeroInflatedPoissonSampler::ZeroInflatedPoissonSampler(
-      ZeroInflatedPoissonModel *model,
-      Ptr<GammaModel> lambda_prior,
-      Ptr<BetaModel> zero_prob_prior,
-      RNG &seeding_rng)
+      ZeroInflatedPoissonModel *model, const Ptr<GammaModel> &lambda_prior,
+      const Ptr<BetaModel> &zero_prob_prior, RNG &seeding_rng)
       : PosteriorSampler(seeding_rng),
         model_(model),
         lambda_prior_(lambda_prior),
-        zero_probability_prior_(zero_prob_prior)
-      {}
+        zero_probability_prior_(zero_prob_prior) {}
 
   void ZeroInflatedPoissonSampler::draw() {
     double p = model_->zero_probability();
     double pbinomial = p;
-    double ppoisson = (1-p) * dpois(0, model_->lambda());
+    double ppoisson = (1 - p) * dpois(0, model_->lambda());
     double nc = pbinomial + ppoisson;
     pbinomial /= nc;
 
@@ -48,10 +46,9 @@ namespace BOOM {
       if (++counter > 1000) {
         report_error("rbeta produced the value 0 over 1000 times.");
       }
-      p = rbeta_mt(rng(),
-                   zero_probability_prior_->a() + nzero_binomial,
+      p = rbeta_mt(rng(), zero_probability_prior_->a() + nzero_binomial,
                    zero_probability_prior_->b() + nzero - nzero_binomial +
-                   model_->suf()->number_of_positives());
+                       model_->suf()->number_of_positives());
     } while (p <= 0.0 || p >= 1.0);
     model_->set_zero_probability(p);
 
@@ -68,10 +65,10 @@ namespace BOOM {
     model_->set_lambda(lambda);
   }
 
-  double ZeroInflatedPoissonSampler::logpri()const{
+  double ZeroInflatedPoissonSampler::logpri() const {
     double ans = zero_probability_prior_->logp(model_->zero_probability());
     ans += lambda_prior_->logp(model_->lambda());
     return ans;
   }
 
-}
+}  // namespace BOOM
